# monochromist

From sketch to contour with transparent background:

![example](doc/images/cat_illustration.png)

Minimum example:
```bash
monochromist -i <input image> -o <output image> -c "<color>"
```

For example:
```bash
monochromist -i doc/images/cat.jpg -o /tmp/cat.png -c "black"
```

For more settings run
```bash
monochromist --help
```